#
# spec file for package python-pygame
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pygame
Version:        2.6.1
Release:        1.1
Summary:        A Python Module for Interfacing with the SDL Multimedia Library
License:        Apache-2.0 AND LGPL-2.1-or-later AND BSD-2-Clause AND BSD-3-Clause AND libpng-2.0
URL:            https://github.com/pygame/pygame
Source0:        %{url}/archive/%{version}.tar.gz#/pygame-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  bitstream-vera-fonts
BuildRequires:  fdupes
BuildRequires:  fontconfig
BuildRequires:  libtiff-devel
BuildRequires:  libudev-devel
BuildRequires:  libv4l-devel >= 0.8.4
BuildRequires:  pkgconfig
BuildRequires:  portmidi-devel
BuildRequires:  python-rpm-macros
BuildRequires:  xorg-x11
BuildRequires:  xorg-x11-fonts
BuildRequires:  xorg-x11-fonts-100dpi
BuildRequires:  xorg-x11-fonts-75dpi
BuildRequires:  xorg-x11-fonts-core
BuildRequires:  xorg-x11-fonts-cyrillic
BuildRequires:  config(fluid-soundfont-gm)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libmpg123)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(x11)
Requires:       fontconfig
Requires:       python-numpy
%ifpython2
Provides:       pygame = %{version}
Obsoletes:      pygame < %{version}
%endif
%python_subpackages

%description
Pygame is a Python wrapper module for the SDL multimedia library. It
contains Python functions and classes that allow you to use SDL's
support for playing CD-ROMs, audio and video output, and keyboard,
mouse and joystick input. Pygame also includes support for the
Numerical Python extension. Pygame is the successor to the pySDL
wrapper project, written by Mark Baker.

%package devel
Summary:        Pygame development package
Group:          Development/Libraries/Python
Requires:       python-pygame = %{version}

%description devel
This package contains the header files for developers of Pygame.

%package -n %{name}-doc
Summary:        Pygame documentation and example programs
Group:          Documentation/Other
Provides:       pygame-doc = %{version}
Obsoletes:      pygame-doc < %{version}
Provides:       %{python_module pygame-doc = %{version}}

%description -n %{name}-doc
This package contains documentation and example programs for Pygame.

%prep
%autosetup -p1 -n pygame-%{version}

sed -i 's/\r$//' docs/reST/ref/code_examples/draw_module_example.py
sed -i 's/\r$//' docs/licenses/LICENSE*.txt
# Fix wrong-script-interpreter
find examples -name '*.py' -exec sed -i "s|^#!.*env python.*$|#!%{_bindir}/python3|" {} \;
chmod a+x examples/*.py
chmod a-x docs/licenses/LICENSE.sdl_gfx.txt

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export PORTMIDI_INC_PORTTIME=1
%pyproject_wheel

%install
export CFLAGS="%{optflags} -fno-strict-aliasing"
%pyproject_install
%{python_expand pushd %{buildroot}%{$python_sitearch}
sed -i "s|^#!.*env python.*$|#!%{_bindir}/$python|" pygame/tests/test_utils/png.py
chmod a+x pygame/tests/test_utils/png.py
chmod a+x pygame/examples/*.py
chmod a-x pygame/examples/__init__.py
popd
}
%python_compileall
%python_expand %fdupes %{buildroot}%{$python_sitearch}
# install docs and examples for doc package and deduplicate
mkdir -p %{buildroot}%{_docdir}/%{name}-doc
cp -r examples docs %{buildroot}%{_docdir}/%{name}-doc/
rm %{buildroot}%{_docdir}/%{name}-doc/examples/.editorconfig
%fdupes %{buildroot}%{_docdir}/%{name}-doc/

%check
export SDL_VIDEODRIVER=dummy
export SDL_AUDIODRIVER=disk
export LANG=en_US.UTF-8
export PYGAME_MSYS2=1
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python -m pygame.tests.__main__ -v --exclude opengl --time_out 300
}

%files %{python_files}
%doc README.rst
%license docs/LGPL.txt
%{python_sitearch}/pygame/
%{python_sitearch}/pygame-%{version}*-info

%files %{python_files devel}
%license docs/LGPL.txt
%{python_sysconfig_var INCLUDEPY}/pygame/

%files -n %{name}-doc
%doc %{_docdir}/%{name}-doc/

%changelog
* Mon Mar  3 2025 Felix Stegmeier <felix.stegmeier@suse.com>
- Update to 2.6.1
  * 2.6.0 -> 2.6.1.dev1 by @illume in #4273
  * grammar-fix by @jakefrombay in #4276
  * Update sprite.rst by @jakefrombay in #4277
  * build(deps): bump actions/checkout from 4.1.6 to 4.1.7 by @dependabot in #4281
  * github: Bump cibuildwheel to v2.19.2 by @illume in #4286
  * Update SpriteIntro.rst by @PavloShutz in #4310
  * buildconfig/appveyor: Python 3.13 for windows by @illume in #4317
  * buildconfig: Pin cython version to range by @illume in #4334
  * build(deps): bump pypa/cibuildwheel from 2.19.2 to 2.20.0 by @dependabot in #4321
  * github/build-*: Fix Cython version specifier by @illume in #4349
  * manylinux: Remove old pypy 3.7 by @illume in #4350
* Wed Sep 11 2024 Markéta Machová <mmachova@suse.com>
- Update to 2.6.0
  * Inline _PyArg_NoKeywords from Python 3.13 in case it is missing
  * Support collide_mask as collided argument in spritecollide
  * Add display argument to pygame.display.list_modes() and pygame.display.mode_ok()
  * Fix numpy.alltrue imports to import all instead
  * Added generics to abstract group for IDE completion
  * Polygon large coordinate test cases for issue#3989
  * Fix go_over_there example bug in Python 3.12
  * Fix wrong ifdef placement for unix/macos
- Drop merged patches:
  * pygame-pr4236-gcc14.patch
  * pygame-pr4169-videodummytests.patch
* Wed May 29 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Cherry-pick upstream patch to fix build with GCC 14
  * pygame-pr4236-gcc14.patch
- Add python-Cython to BuildRequires
- Switch upstream source to GitHub to avoid generated C code
* Fri Mar 29 2024 ecsos <ecsos@opensuse.org>
- Fix build error in Leap 15.6.
* Fri Mar  8 2024 Ben Greiner <code@bnavigator.de>
- Skip failing tests with dummy video driver on SDL2
  * Add pygame-pr4169-videodummytests.patch gh#pygame/pygame#4169
* Sat Dec 30 2023 Dirk Müller <dmueller@suse.com>
- update to 2.5.2:
  * Added a gamepad mapping for the G-Shark GS-GP702
  * Fixed touchpad events for the Razer Wolverine V2 Pro in PS5
    mode
  * Fix white bar in docs
  * manylinux: Fix sdl version typo
  * include: rect: C API docs for Rect
  * draw: Fix arc width > 1 so it doesn't have gaps
  * setup: tox: Add 31 and 32 to list of pythons
  * docs: c_api/rect: Fix return code for pgRect_Check
  * setup: src_c: Require Cython to generate source files in dev
  * Added import information in camera and sdl2 controller
    modules docs
  * Fix: Grammatical Error in MoveIt.rst
  * examples: Fix music_drop_fade with type checker
  * stubs: Add pygame.__version__ to type stubs
  * gitignore: Add cython generated files to ignore list
  * examples/midi: Refactor to fix typing issues
  * display set_mode: Remove SDL_WINDOW_FULLSCREEN_DESKTOP
  * buildconfig/manylinux: Bump SDL 2.28.3
  * docs: Fix READMEs with a good Sphinx version
- update to 2.5.1:
  * Fixed crash at shutdown when using the D3D11 renderer
  * Fixed setting the viewport when using the D3D12 renderer
  * Fixed 8BitDo gamepad mapping when in XInput mode on Linux
  * Fixed controller lockup initializing some unofficial PS4
    replica controllers
  * Fixed video initialization on headless Linux systems using
    VNC
  * Fixed large mouse jump when changing relative mouse mode on
    macOS
  * Fixed hardware keyboard text input on iPadOS
  * Added support for the Nintendo Online Famicom controllers
  * Improved support for third-party Nintendo Switch controllers
  * Fixed setting the player LED on Nintendo Switch controllers
  * Added Linux controller mapping for the Logitech Chillstream
  * Fixed appending to a file greater than 4GB in size on Windows
* Mon Sep 11 2023 Lubos Kocman <lubos.kocman@suse.com>
- Correction of licenses based on the diff against old report
  Add libpng-2.0, Apache-2.0, BSD. Ignoring FTL as fonts seem
  to be only referenced in tests.
* Wed Aug  9 2023 Dominik George <nik@naturalnet.de>
- Update to 2.5.0
  * Wayland oh wayland, goodbye manylinux1, ciao manylinux2010 by @illume in #3841
  * github: Add python 3.12-dev to the test matrix by @illume in #3847
  * mixer: Testing by @illume in #3846
  * Add support for keyboard grab without mouse grab (expose SDL_GetWindowKeyboardGrab) by @Yannik in #3843
  * SDL 2.26.5 by @illume in #3848
  * Updated event_name function to use kwargs by @jonotassia in #3854
  * manylinux: Add Secret Rabbit Code for better sound quality by @illume in #3855
  * base: Some of it documented by @illume in #3856
  * Adding kwarg support to color.c by @jonotassia in #3858
  * Add keyword argument support to display.c by @jonotassia in #3859
  * color: Fix color.c from weird merge issue by @illume in #3862
  * SDL2 mixer 2.6.3 by @illume in #3861
  * Fix types for aliens by @illume in #3864
  * types eventlist by @illume in #3865
  * types midi by @illume in #3866
  * types video by @illume in #3867
  * examples midi: Fix some 3.10isms in the typing by @illume in #3868
  * examples: types textinput by @illume in #3870
  * examples: types scroll by @illume in #3869
  * test mixer: Fix test_play_multiple_times to be more CI friendly by @illume in #3871
  * Overhaul of README for pygame/examples by @bakkary23 in #3873
  * test time: Fix for unrealistic time slice requirement by @illume in #3878
  * time: Document and clean up a few functions by @illume in #3879
  * Added kwarg handling to rect.c by @jonotassia in #3872
  * es docs by @illume in #3884
  * Add Spanish version of bufferproxy.rst by @stefpivser in #3885
  * Add Spanish version of camera.rst by @stefpivser in #3886
  * Add Spanish version of cursors.rst by @stefpivser in #3888
  * Add Spanish version of color.rst by @stefpivser in #3889
  * Add Spanish version of cdrom.rst by @stefpivser in #3890
  * Spanish Version of c_api.rst by @stefpivser in #3893
  * Add Spanish Version of index.rst by @stefpivser in #3894
  * Add Spanish version of logos.rst by @stefpivser in #3895
  * Add Spanish Version of README.md by @stefpivser in #3896
  * Add Spanish Version of color_list.rst by @stefpivser in #3897
  * rwobject.c: Use lseek64(3) only for GNU libc by @saper in #3898
  * manylinux: Add libdecor by @illume in #3900
  * examples/stars: Improve typing by @illume in #3901
  * examples/dropevent: Fix typing issue by @illume in #3902
  * examples/dropevent: A few minor cleanups by @illume in #3904
  * examples/testsprite: Fix a few minor typing and code style issues by @illume in #3903
  * examples: Remove prevent_display_stretching and fix stars typing issue by @illume in #3905
  * es doc references fixups by @illume in #3909
  * 2.5.0.dev2 -> 2.5.0.dev3 by @illume in #3910
  * Update documentation on several events by @RyanNicoletti in #3912
  * setup buildconfig github: Add PYGAME_DETECT_AVX2 to unfsk setup by @illume in #3924
  * github: Bump pypa/cibuildwheel@v2.13.1 by @illume in #3925
  * buildconfig: 3.12 part 2 - the cpython strikes back by @illume in #3927
  * key: Allow list(get_pressed()) again by @illume in #3926
  * Updating "Python Pygame Introduction" by @Ronoc21 in #3918
  * Added "Contribute" section to main README.rst by @gezeebeezee in #3919
  * docs: Remove linenos because it breaks github rendering by @illume in #3928
  * docs: Add sphinx conf for docs/es by @illume in #3929
  * Unit tests added to mixer.music test module by @LegoPCT20 in #3921
  * mixer.music: Add missing unit tests by @LegoPCT20 by @illume in #3931
  * alphablit: Add env var to warning message by @illume in #3935
  * buildconfig: SDL 2.28.0 by @illume in #3936
- Update to 2.4.0
  * 2.3.0 -> 2.4.0.dev1 by @illume in #3760
  * Fix docs for cursors.Cursor.copy() by @MarcellPerger1 in #3762
  * base: Remove pygame_parachute by @illume in #3768
  * mouse mouse_get_rel: Fix for SCALED by @illume in #3769
  * github: Remove unused files by @illume in #3771
  * buildconfig: SDL 2.26.4 by @illume in #3770
  * sysfont: Fix sysfont on macos on failure of fc-list by @illume in #3772
  * 2.4.0.dev2 by @illume in #3774
  * manylinux: Add libxml, wayland, wayland-protocol dependencies by @illume in #3775
  * fixed self.pos of move method in GameObject in Moving Multiple Images by @saif-11bit in #3783
  * docs: Add Spanish version of MoveIt.rst by @stefpivser in #3810
  * docs: Add Spanish version of SpriteIntro.rst by @stefpivser in #3811
  * docs: Add Spanish version of SurfarrayIntro.rst by @stefpivser in #3812
  * docs: Add Spanish version of tom_games2.rst by @stefpivser in #3813
  * docs: Add Spanish version of tom_games3.rst by @stefpivser in #3814
  * docs: Add Spanish version of tom_games4.rst by @stefpivser in #3815
  * docs: Add Spanish version of tom_games5.rst by @stefpivser in #3816
  * docs: Add Spanish version of tom_games6.rst by @stefpivser in #3817
  * docs: Add Spanish translation of newbieguide.rst by @stefpivser in #3808
  * docs: Add Spanish version of CameraIntro.rst by @stefpivser in #3809
  * Add documentation for DualShock 5 by @Aashutosh-922 in #3797
  * Fix the signature of midi.get_device_info by @SpeedyOrc-C in #3807
  * Fix some docs warnings by @illume in #3825
  * base: Document some of the things by @illume in #3826
  * Replaced dict with weakset in Sprites groups by @theRealProHacker in #3766
  * Weak sprites, part 2 by @illume in #3827
  * draw.circle: Fixes when center is -x, and bounding rect by @illume in #3779
- Update to 2.3.0
  * 2.2.0 -> 2.3.0.dev1 by @illume in #3736
  * Remove :return from sysfont._parse_font_entry_win by @MarcellPerger1 in #3732
  * Add special_flags argument to Group.draw by @MarcellPerger1 in #3722
  * Add Spanish version of ImportInit.rst by @stefpivser in #3699
  * Add Spanish version of DisplayModes.rst by @stefpivser in #3700
  * Add Spanish version of CreateGames.rst by @stefpivser in #3714
  * buildconfig: Bump SDL version to 2.24.2 on windows by @illume in #3458
  * _camera_opencv: Add list_cameras implementation by @illume in #3738
  * github sdist: Do not apt-get update by @illume in #3740
  * Fixup deprecation error on MacOS 11 by @Tobias-Fischer in #3663
  * manylinux-build: Bump SDL2 to version 2.24.2 by @illume in #3741
  * _camera_opencv: Add ability to pass VidCapture api_preferences by @illume in #3739
  * 2.3.0.dev2 -> 2.3.0.dev3 by @illume in #3742
  * camera: Make opencv backend default on win if cv2 imports by @illume in #3743
  * Features/rect/scaleby by @dr0id in #3077
  * Implement pygame.math.lerp by @JamesC01 in #3362
  * Defining rect assignment of floats to Rect properties by @dr0id by @illume in #3745
  * Rect: scale_by and scale_by_ip by @dr0id and @mcpalmer1980 by @illume in #3746
  * circleci: Remove config by @illume in #3748
  * docs: fix move images tutorial final example by @SalimBAhmed in #3747
  * Fix drawing of circles there intersect -+INT_MAX by @jhilmer in #3151
  * Implementation of Vector2.from_polar and ClassObjectMethod descriptor by @joaquin30 in #3744
  * github: Add back apt-get update / upgrade by @illume in #3751
  * _sdl2.video: Window.from_window by @Rabbid76 by @illume in #3752
  * class method "from_foreign_window" added to class "Window" by @Rabbid76 in #2982
  * draw mask: Added unit tests for test_arc and test_angle by @yujyuj by @illume in #3753
  * examples: Add grid movement example by @Masonstiller by @illume in #3754
  * docs: Fix a few sphinx warnings by @illume in #3759
  * Fix segfaults when using display surface after calling pygame.quit by @MarcellPerger1 in #3755
- Update to 2.2.0
  * docs: Add experimental feedback links to new APIs by @illume in #3511
  * 2.1.4.dev1 by @illume in #3514
  * Fix 2.1.4 build by @Starbuck5 in #3529
  * Change from clang-format update (needed for CI) by @MyreMylar in #3535
  * Fix memory leak for distance_to() by @novialriptide in #3532
  * Fixed inconsistency in tp_names, changed all to pygame.module.Type by @Matiiss in #3515
  * Add 3.11 classifier by @novialriptide in #3537
  * Tracking SSE2 Optimisations by @PurityLake in #3370
  * Tweaking version getters for sdl modules and freetype by @oddbookworm in #3379
  * Warn when SIMD is usable but not compiled by @ankith26 in #3501
  * Changed minor name mismatch by @Matiiss in #3544
  * Document SDL_JOYSTICK_ALLOW_BACKGROUND_EVENTS by @zoldalma999 in #3546
  * Move pg_tuple_from_values_int into header, rename & add triple variant by @MyreMylar in #3530
  * mouse.get_pos(), mouse.get_rel() optimizations by @itzpr3d4t0r in #3424
  * Minor typo in the "pygame.Color" docs by @pgattic in #3554
  * Remove Python < 3.2 compatibility shim by @Starbuck5 in #3553
  * docs: fix links by @Linkid in #3549
  * Fix typo in music.rst by @winterhazel in #3562
  * Delete test_test_.py by @Koswu in #3563
  * Add info on viewing pygame docs locally by @novialriptide in #3558
  * Modify key compat table to store key-name pairs (fixes a rare bug) by @ankith26 in #3426
  * Adjust surface masks to create a proper 24 bit Surface by @Starbuck5 in #3577
  * Add vector zero constructor clarification by @novialriptide in #3574
  * Minor pygame.math doc enhancements by @Matiiss in #3581
  * Improved colliderect() function by @itzpr3d4t0r in #3322
  * Add VScode? _headers/ folder to gitignore by @Starbuck5 in #3587
  * Remove LGTM badges by @novialriptide in #3599
  * Fix list_cameras being empty on linux by @ankith26 in #3594
  * Fix some more math memory leaks by @ankith26 in #3590
  * Use Python 3.11.0 rather than 3.11rc2 by @Starbuck5 in #3611
  * Add quickstart section to docs front page by @Starbuck5 in #3541
  * Add premul_alpha method to surface by @MyreMylar in #3276
  * Add "window" attribute to DROPFILE and DROPTEXT event by @yunline in #3568
  * Fix minor grammar and punctuation mistakes in tom_games6.rst by @cvionis in #3616
  * Added __round__ method for vectors by @Matiiss in #3559
  * Segfault fix in freetype.get_version by @oddbookworm in #3567
  * Convert surface to texture's pixel format in Texture.update by @zoldalma999 in #3548
  * Performance improvement for draw.circle by @MightyJosip in #3550
  * Fix build errors on win_arm64 by @cgohlke in #3583
  * Consolidate SSE2 and NEON code paths by @Starbuck5 in #3588
  * Correct set_(shifts/masks) docs and cleanup code by @Starbuck5 in #3620
  * Update README.rst by @CodeMaster7000 in #3625
  * Deprecate gamma and _sdl2 window brightness functionality by @SSS-Says-Snek in #3622
  * Change all (to|from)string to (to|from)bytes in image.c by @Matiiss in #3633
  * Update docs generation to sphinx 6.0 by @MyreMylar in #3647
  * Raise minimum SDL version to 2.0.8 by @Starbuck5 in #3618
  * Replace music.set_pos current error message with SDL_GetError() by @Matiiss in #3641
  * Fixed typo in pygame.image.tobytes docs by @oddbookworm in #3657
  * Update README.rst by @SmashedFrenzy16 in #3638
  * fixed segfault by @oddbookworm in #3666
  * Fix event button attr for fast mousewheel by @ankith26 in #3642
  * Change casting to list to using copy in pygame.sprite by @Matiiss in #3655
  * Removing redudancy in regex by @TheVroum in #3595
  * Remove bit of MIR code by @Starbuck5 in #3617
  * Fix scrap typing (use only bytes and not AnyStr) by @ankith26 in #3395
  * wasm: clean up for #3439 by @pmp-p in #3593
  * Syntax highlighting fix by @novialriptide in #3684
  * Port SDL_ttf text shaping capability by @Starbuck5 in #3330
  * Fix the memory leak by @Starbuck5 in #3649
  * Update linter ubuntu version by @MyreMylar in #3689
  * Linter run by @novialriptide in #3695
  * Correct update statement by @chimosky in #3694
  * Update sprite.rst by @Librichard in #3648
  * Re-order display fullscreen handling and ensure toggle_fullscreen works for maximized window by @Temmie3754 in #3497
  * Fix the fault of stubtest by @yunline in #3703
  * Don't set adaptive vsync by default by @fladd in #3609
  * Add support for ppc64le by @mgiessing in #3605
  * Example games fixed | Fixed UnicodeDecodeError for music_drop_fade.py… by @Vazno in #3387
  * Updated README.rst to include feature description by @ChristianKearns in #3710
  * pgScancodeWrapper now raises exception when trying to use iter by @PurityLake in #3495
  * Suggested improvement to font_init by @PurityLake in #3489
  * grayscale for Surfaces and Colors by @ScriptLineStudios in #3556
  * "SDL_CreateWindowFrom" in "display" module by @Rabbid76 in #2981
  * github build-macos: Add pkg-config dependency by @illume in #3716
  * Fix SDL_WINDOWID with SDL by @Rabbid76 by @illume in #3718
  * Add grayscale for surfaces and colors by @ScriptLineStudios by @illume in #3717
  * 2.1.3 -> 2.2.0.dev1 by @illume in #3711
  * Add a simple check for mypy by @illume in #3723
  * manylinux: Revert compiling harfbuzz on MacOS by @illume in #3724
  * manylinux: Add more pythons to be built with by @illume in #3725
  * Fix of inverted boolean of borderless window property by @joaquin30 in #3727
  * That time numpy was giving me grief by @illume in #3731
- Remove upstreamed patch adjust-surface-mask.patch.
- Switch from %%python_{build,install} to %%pyproject_{wheel,install} macros.
* Sun May  7 2023 Jan Engelhardt <jengelh@inai.de>
- Replace xorg-x11-devel by pkgconfig(...)
* Thu Feb 23 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 2.1.3:
  * 2.1.2 by @illume in #2957
  * Fix path dependencies by @SergioArnaud in #2975
  * Add test for pygame.locals by @ankith26 in #2958
  * Fix Pygame imported class typehints by @MightyJosip in #2965
  * Fix some bugs in camera.py by @ankith26 in #2961
  * Clean modinit C code, fix bugs, use recommended API by @ankith26 in #2952
  * Python2 to Python3 code modernization by @novialriptide in #2984
  * SDL 2.0.20 by @illume in #2983
  * Update the image doc, delineate bytes and str by @Starbuck5 in #2959
  * Add pixel format name into display info by @MyreMylar in #2964
  * Add missing copy test for Vector3 by @JovialKnoll in #3000
  * New black formatting by @novialriptide in #3013
  * Misc fixes: Fix UCS_4 UCS4 typo, incorrect color methods export and display.c error handling bugs by @ankith26 in #2987
  * Snake casify _sdl2.video.Image.flipX and .flipY by @avaxar in #2978
  * Removed unused imports by @novialriptide in #3016
  * Fix warnings, make warnings error on CI by @ankith26 in #2919
  * Added Rect typing and docs that it is iterable by @novialriptide in #2969
  * Fix there typo in tests.rst by @eoghanriley in #3022
  * C code cleanups + cdrom/overlay removal by @Starbuck5 in #3014
  * Make sure surfaces start as opaque black. (MacOS) by @Starbuck5 in #2973
  * Add transform.scale_by, transform.smoothscale_by functions by @Starbuck5 in #2723
  * Fix typo in C_api display docs by @gresm in #3027
  * Font rwops by @Starbuck5 in #2911
  * transform.average_color: Add optional parameter 'consider_alpha' to remove black artifacts if alpha present by @dr0id in #2968
  * pygame.docs: remove warning in docs generation due to a reference to… by @dr0id in #3029
  * Add __new__ and __init__ functions for some types by @zoldalma999 in #3001
  * Regenerate cython files by @ankith26 in #3032
  * 2.1.3.dev2 by @illume in #3039
  * Add .move_towards() for Vector2 and Vector3 by @novialriptide in #2929
  * Save Surfaces with palettes as indexed 8P PNG by @ThanhChinhBK in #3028
  * Rect collidelistall unittests added and updated docs to document different argument types by @dr0id in #2989
  * Add some more events by @ankith26 in #2953
  * Fix bufferproxy doc typo by @gresm in #3044
  * VideoInfo string missing closing parenthesis by @GregoryMorse in #3053
  * Fix stubtest warnings, run stubtest on CI by @ankith26 in #2999
  * Cursors example improvements - including showing new system, color, and image cursors by @thanice in #3037
  * Improve example textinput by @blankRiot96 in #3050
  * Use github downloads for windows prebuilts downloads by @illume in #3059
  * 2.1.3.dev4 and 2.1.3dev5 by @illume in #3060
  * Fix more typestub warnings with dunders by @ankith26 in #3075
  * Fix APPMOUSEFOCUS naming, update const values by @ankith26 in #3043
  * Pkgdata import in init for PyInstaller by @Starbuck5 in #3082
  * Fix logos page by @Grimmys in #2977
  * Fix segfault in resource loading function by @ankith26 in #3089
  * Fix pygame logo image in README.rst by @novialriptide in #3090
  * Add black badge by @novialriptide in #3091
  * Use static dot declarations for type objects by @ankith26 in #3067
  * Windows prebuilts updates with freetype and SDL_ttf 2.0.18 by @Starbuck5 in #3086
  * Get rid of sprintf calls in the codebase by @ankith26 in #3041
  * Fix and normalize function pointer calls for METH_NOARGS by @pmp-p in #3080
  * Update list of datafiles in generated docs by @wxh06 in #3073
  * Improve draw doc accuracy and example style by @Starbuck5 in #3074
  * Check SDL version earlier, report known incompat (closes #2657) by @SnoopJ in #2661
  * Lint/format examples/*.py by @Starbuck5 in #3093
  * Fix missing pointer cast fix by @pmp-p in #3104
  * Add a .clamp_magnitude() to Vector2 and Vector3 by @novialriptide in #2990
  * examples/mask.py change default image to one with alpha channel by @brccabral in #3111
  * Fix mouse_get_pos takes no argument by @pmp-p in #3115
  * Small fixes to the documentation header by @hnrkcode in #3094
  * Rect and Color support collections.abc.Container, add tests and stubs by @ankith26 in #3066
  * Don't raise python errors in v4l2_read_frame by @ankith26 in #3052
  * Fix name/definition conflict for pgSurface_New by @pmp-p in #3106
  * Add pygame.font.get_sdl_ttf_version() for getting version of SDL_ttf library by @mariospapaz in #3095
  * Math's Vectors have not documented methods by @gresm in #3122
  * Event tests and types improvements (Minor event refactor part 3) by @ankith26 in #3063
  * Cleanup old compatibility code in windows sysfont by @Starbuck5 in #3126
  * Fix display.set_mode docs for DOUBLEBUF by @Starbuck5 in #3129
  * Make pgBuffer_Release retain previously set errors by @ankith26 in #3127
  * Change renderer names to strings in get_drivers by @zoldalma999 in #3132
  * Takeover of Newbie guide PR #2718 by @davidpendergast by @MyreMylar in #3118
  * Fixed Vector.clamp_magnitude() parameters by @novialriptide in #3133
  * SIMD version of BLEND_RGBA_MULT for 32bit surfaces by @MyreMylar in #2988
  * Update constants.c to clang-format version 14.0 by @MyreMylar in #3137
  * Add pygame.context module by @Starbuck5 in #3100
  * Add pygame.get_pref_locales by @ankith26 in #3038
  * Use more optimal line functions in polygon by @Starbuck5 in #3141
  * Proposal: add Rect.collidelistallobjects that returns the colliding objects by @dr0id in #3026
  * Remove Solaris compatibility code to re-enable SIGALARM by @MyreMylar in #3142
  * Fix Vector subclass methods to return the correct subtype instance by @novialriptide in #3088
  * Raise only pygame.error when mixer loading fails by @ankith26 in #3148
  * Fix typo in SpriteIntro.rst tutorial by @JoshuaDRose in #3154
  * Fixed windows version parsing in Camera that errored on versions like 8.1 by @Matiiss in #3158
  * Fix "-auto" setup.py argument not being used properly in buildconfig by @robertpfeiffer in #3157
  * Updates to moveit.py example by @dbrown3562 in #3146
  * Update to SDL 2.0.22 on Windows by @Starbuck5 in #3162
  * Typo fix, ball -> bat by @elgcodes in #3164
  * Typo fix or -> for by @elgcodes in #3165
  * Fix sysfont.get_fonts stop returning None, warn fc-list issues by @ankith26 in #3159
  * Fix _sdl2.controller for static build, pygame.h is in _sdl2 parent directory by @pmp-p in #3105
  * Add SIMD versions of RGB_MUL blitter by @MyreMylar in #3136
  * Fix typo in korean document by @EunhoKang in #3176
  * Add evfilter guard mutex, fix pymalloc without GIL (Minor event refactor part 2.1) by @ankith26 in #3177
  * Add test for fullscreen toggle by @PurityLake in #3171
  * SIMD versions of RGB_ADD, RGBA_ADD, RGB_MUL & RGBA_MUL by @MyreMylar in #3170
  * Static build support for WebAssembly by @pmp-p in #3108
  * Correction of a comment by @Yvant2000 in #3182
  * Regenerate cython files by @Starbuck5 in #3183
  * Simplify some boolean handling by @Starbuck5 in #3192
  * Fix DLL loading problems on Windows Store Python installations by @Starbuck5 in #3196
  * wasm: fence simd/avx by @pmp-p in #3191
  * Removed Python 2 nonzero by @blankRiot96 in #3194
  * Use CircleCI for manylinux aarch64 builds by @ankith26 in #3188
  * Remove custom JPEG saver by @Starbuck5 in #3180
  * Update build-emsdk.yml by @pmp-p in #3185
  * Improve clang format source file detection by @zoldalma999 in #3140
  * Clang format touch.c to fix failing lint tests by @ankith26 in #3201
  * Fix Chimp tutorial code to use the correct module name alias by @kharissa in #3205
  * Fix a few pylint issues by @ankith26 in #3206
  * pyupgrade --py36-plus **/*.py by @cclauss in #3208
  * Fix print () --> print() by @cclauss in #3213
  * Make latest pypy wheels on mac/linux, cibuildwheel on manylinux and other minor updates by @ankith26 in #3187
  * Remove more code for legacy Python by @cclauss in #3207
  * More Python f-strings with flynt by @cclauss in #3212
  * Add SIMD versions of RGB & RGBA BLEND_MAX, BLEND_MIN blit modes by @MyreMylar in #3181
  * Use custom SDL2_ttf on Windows by @Starbuck5 in #3193
  * Typos: get em out of here! by @Starbuck5 in #3216
  * setup.cfg: Sort pylint disables to simplify future edits by @cclauss in #3220
  * sysfont.py: check for emscripten platform by @pmp-p in #3225
  * Fix undefined name: get_python_inc() by @cclauss in #3219
  * Added strikethrough option to Font by @MightyJosip in #2991
  * Fixed window not staying centered on second call of display.set_mode by @PurityLake in #3172
  * Fix Vector memory leak by @MightyJosip in #3236
  * wasm disable mutex usage, wasm CI updates by @ankith26 in #3203
  * wasm: pygame.surfarray could load on 3.10.5 backport by @pmp-p in #3246
  * Refactor font.render by @Starbuck5 in #3186
  * Fix Controller.rumble returning wrong bool on error by @ankith26 in #3248
  * wasm: wrong logic masks pgExc_SDLError by @pmp-p in #3247
  * Make textinput show a candidate list by @Starbuck5 in #3244
  * Cleaned up test/README.TXT by @novialriptide in #3254
  * Fix typos in sprite docs by @StarDexterity in #3263
  * Fix Surf.set_palette to be usable without an initialized display by @Starbuck5 in #3259
  * Replaced some truth testing with is not None checks in sprite module by @Matiiss in #3271
  * Include user fonts for pygame.font.match_font() on Windows by @novialriptide in #3184
  * Add SysFont pygame.font.get_fonts() verification test by @SSS-Says-Snek in #3266
  * Fix wasm build when no PREFIX variable is defined by @ryanking13 in #3280
  * Remove deprecated blend argument from test and docs by @kevin-pease in #3281
  * Fix controller build on SDL < 2.0.9 by @Starbuck5 in #3272
  * Add unit test for display.gl_set_attribute() by @MyreMylar in #3256
  * Fix docs and types for math.Vector2.cross() return to float by @Vicky-Vicky27 in #3286
  * Prettify joystick documentation + add Nintendo Switch mapping by @novialriptide in #3290
  * Sprite typestub updates, use generics and protocols by @ankith26 in #3138
  * Adjusted examples and rewrote documentation accordingly by @dbrown3562 in #3092
  * More efficiently track pixels in AVX blitters by @Starbuck5 in #3294
  * Fix sprite docs DrawPlain ---> RenderPlain by @fQ7N in #3298
  * Fix new static analyzer (VS 2022) warnings by @ankith26 in #3295
  * Cleaned up draw.aaline() code for small speedup by @itzpr3d4t0r in #3300
  * wasm: add pygame.gfxdraw to static preloader by @pmp-p in #3304
  * Raise minimum SDL to 2.0.4, patch so it can build on that by @Starbuck5 in #3239
  * Update SDL_ttf 2.20.0, SDL_mixer 2.6.0 on Windows by @Starbuck5 in #3287
  * Restore correct checksum for SDL_ttf windows dep download by @itzpr3d4t0r in #3329
  * setup.py: fix user+deprecation warnings on 3.11+ by @pmp-p in #3228
  * Add FASTCALL compat macros, update Color.update to use the same by @ankith26 in #3325
  * Fix latest stubtest issues by @ankith26 in #3332
  * Fix wrong relative imports in _sdl2 cython code by @pmp-p in #3313
  * Add use_compat to key.name, fix key_code compat issues by @ankith26 in #3312
  * Add srcrect NULL check to pgSurface_Blit by @MyreMylar in #3284
  * Add BGRA format for pycairo compatibility by @rlatowicz in #3338
  * Move alphabit.c SSE2 blitters to main SSE2 file by @Starbuck5 in #3296
  * Surface.blits() speedups and code cleanup by @itzpr3d4t0r in #3314
  * Optimized _vector_distance_helper by @itzpr3d4t0r in #3335
  * Use macos-12 for all Mac CI builds by @ankith26 in #3347
  * Added tobytes/frombytes aliases for pygame.image.(to|from)string by @Emc2356 in #3321
  * Remove constants repetition and duplicate define by @Starbuck5 in #3344
  * Add clamp(val, min, max) function to pygame.math by @JamesC01 in #3326
  * BGRA format added to fromstring & tostring by @rlatowicz in #3342
  * Use memcpy and memset when appropriate by @Starbuck5 in #3364
  * SDL_UCS4ToUTF8 may exist from SDL_keyboard.c by @pmp-p in #3349
  * edited docs for pygame.Vector2.angle_to by @oddbookworm in #3359
  * Deprecate Color.set_length by @blankRiot96 in #3352
  * Vendor in SDL PNG save function, fix new 2.1.3 regression by @ankith26 in #3376
  * Merge 32/64bit SSE blitter codepaths by @Starbuck5 in #3375
  * Document pygame.math.Vector epsilon attribute by @oddbookworm in #3373
  * test.test_utils.run_tests.py: Fix exit using RuntimeError for better message by @Vazno in #3382
  * Cleanup sysfont.py to use f-strings by @lebedevhhh in #3391
  * setup.py | io module no longer used. by @Vazno in #3388
  * Update DisplayModes.rst - PEP Changes by @JoshuaDRose in #3385
  * Fix some METH_NOARGS usage, use METH_O where possible by @ankith26 in #3366
  * Make pygame.math.clamp only take numbers by @JamesC01 in #3361
  * Add _GenericVector to math typestubs, fixes by @ankith26 in #3150
  * Fix tests that had overshadowed names by @ankith26 in #3384
  * Replaced more expressions to f strings by @Vazno in #3392
  * scale(), scale_by(), smoothscale(), smoothscale_by() reorganization and speed up by @itzpr3d4t0r in #3319
  * config_unix: Removed unused sys import by @Vazno in #3397
  * Fix edge case bug in Vector.move_towards, add more tests by @ankith26 in #3400
  * Go back to old memcpy strategy for non-flip flip by @Starbuck5 in #3416
  * Fix incref issue in PixelArray context manager API by @ankith26 in #3414
  * Update some deps in manylinux scripts by @ankith26 in #3042
  * Fix freetype compilation flags when building with clang instead of gcc by @pmp-p in #3381
  * Relax SDL minor version exact match check by @ankith26 in #3428
  * Clean bash-completion file in macdeps builds by @ankith26 in #3431
  * Optimized rect getters by @itzpr3d4t0r in #3401
  * Delete rect subscripts should error not segfault by @ankith26 in #3440
  * Vector clamp shouldn't allow kwargs, improve error reporting and unit tests by @ankith26 in #3396
  * Make sure set_mode always returns a cleared window by @ankith26 in #3317
  * Improved mixer.set_reserved() documentation by @Vicky-Vicky27 in #3434
  * SSE alpha blitter optimization by @Starbuck5 in #3378
  * Add Spanish translation of chimp tutorial by @stefpivser in #3421
  * Update and sync SDL_mixer and SDL_ttf to 2.6.2 and 2.20.1 respectively by @ankith26 in #3433
  * Compile freetype with harfbuzz, reduce manylinux wheelsize by @ankith26 in #3445
  * Freshen up arraydemo.py by @Starbuck5 in #3453
  * Refactor examples/mask.py by @pycoinfu in #3455
  * Fix new mypy-0.981 fails by @ankith26 in #3470
  * 2.1.3.dev6 and 2.1.3.dev7 by @illume in #3471
  * Fix pypy rect freelist issue, unskip tests by @ankith26 in #3452
  * Fix es folder location and fix some sphinx issues in ChimpanceLineaporLinea.rst by @illume in #3473
  * Fixed typo in aliens example by @muelletm in #3485
  * overview.rst -> 개요.rst by @novialriptide in #3474
  * Add 3.11.0.rc2 to Appveyor by @Starbuck5 in #3486
  * Cleanup of symbian code and references to bitbucket/motherhamster bugzilla by @ankith26 in #3490
  * Fixed segault in subclass of Sound by @PurityLake in #3492
  * Relax strict pixel match tests in test_src_alpha_sdl2_blitter by allowing a small delta by @Temmie3754 in #3494
  * manylinux: Upgrade to SDL2-2.0.22 by @illume in #3475
  * Internalize "SDL"_UCS4ToUTF8 by @Starbuck5 in #3487
  * blitters fix compile error when no SIMD by @ankith26 in #3498
  * Python 3.11 on mac/manylinux (with updated cibuildwheel) by @ankith26 in #3484
  * v2.1.3.dev8 by @illume in #3503
  * Remove pygame.context for later renaming by @illume in #3508
  * Correct typo in tom_games3.rst by @cvionis in #3504
  * Add debian s390x and ppc64le tests to CI by @ankith26 in #3496
  * docs: Add experimental feedback links to new APIs by @illume in #3511
* Mon Dec 12 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add adjust-surface-mask.patch gh#pygame/pygame#3577, to fix tests with SDL
  2.26.0.
* Fri Aug 12 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add build dependency on libmpg123 because it is required for the tests
* Fri Feb  4 2022 Dirk Müller <dmueller@suse.com>
- fix portmidi configuration detection
* Wed Jan  5 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.1.2:
  * Fix segfault in display.update by @ankith26 in #2954
  * Quick fix to get 'python -m pygame.docs' working by @ankith26 in #2955
  * Working gamma test on windows by @MyreMylar in #2906
  * Freetype: Fix intermittent crash with test_font_file_not_found by
    @illume in #2944
  * Officially drop python2 (and 3.5) and SDL1 support by @Starbuck5 in #2817
  * Remove most PY2/PY3 C compatibility code by @Starbuck5 in #2819
  * Simple fix to swap numpy.float type out in favour of float by
    @MyreMylar in #2815
  * Remove most SDL1/SDL2 compatibility c code by @Starbuck5 in #2823
  * Ubuntu 18/20 SDL2 sdist CI, mac CI pp36 drop by @ankith26 in #2821
  * SDL1 buildconfig removal by @robertpfeiffer and @illume in #2824
- Drop support-SDL2-2.0.16.patch.
* Thu Sep 16 2021 Matej Cepl <mcepl@suse.com>
- Add support-SDL2-2.0.16.patch swtiching off
  tests.video_test.VideoModuleTest.test_renderer_set_viewport
  (gh#pygame/pygame#2721 and gh#pygame/pygame#2670) on 32bit
  systems for incompatibility with SDL2 2.0.16.
* Tue Apr 27 2021 Ben Greiner <code@bnavigator.de>
- Explictly require libudev while building (for staging)
* Tue Mar 23 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.0.1 The Age Of Aquarius release
  * This is a bug fix release, with a bunch of features and
    optimizations thrown in for good measure.
  * Backwards compatibility fixes
  * Major event refactor
  * Color.update() and Rect.update()
  * SDL 2.0.14
  * Xbox One port
  * pathlib support for image, sound, and font loading.
  * Cursor object API
  * pygame.draw.rect fixes.
- pygame 2.0 - the happy dance birthday release
  * Support for Metal, Direct 3d, Vulkan, OpenGL 3.0+ in various
    profiles (core, compatibility, debug, robust, etc), OpenGL ES,
    and other modern hardware accelerated video APIs across many
    platforms.
  * SSE2/Neon assembly image drawing. Much faster drawing
    routines, image loading, and alpha blending.
  * Type Hints, for code completion (and to help you make the
    squiggly lines disappear) in editors and IDEs.
  * Code cleanup, using lots of code robustness tools like static
    analyzers, and automated CI/CD. We've been able to help dozens
    of people new to community projects contribute. We have lots
    of work to go on code quality, but we're currently the highest
    rated Python and highest rate C large project on LGTM.
  * Many, many bug fixes including in our pygame.draw routines,
    pygame.math(for vectors), and pygame.mask for pixel perfect
    collision detection.
  * better support for PyPy (the fast JIT based implementation of
    python). See our milestone Are we pypy yet? No. for our
    progress on making PyPy the best python for games.
  * libsdl version 2 support. Technically pygame 2.0 still works
    with SDL 1, but we recommend SDL2 which is vastly improved
    over SDL1 for most use cases. Probably we will remove SDL 1
    support starting pygame 2.1.
  * Touch support (multitouch, gestures, etc)
  * Audio input support (make games with your microphone!).
  * Message alert boxes (Press OK, or Cancel).
  * Better keyboard support. Proper unicode input and IME support.
  * Much improved game controller support.
  * Better image and audio format support. Including: webp, 32bit
    wav files, and much more reliable mp3 support.
  * Multiple display support, and multiple window support (multi
    window support is still experimental, more will come in pygame
    2.1).
  * Android support through python for android (fork of pygame
    subset for android). Better documentation, and better support
    will come in future releases.
  * to make distributing your apps easier, a built in "pyinstaller
    hook"and compatibility with cxfreeze.
  * binary "wheels" on many platforms and versions of python from
    the old python 2.7 - to the latest python 3.9 (and with pypy!).
  * lots of quality of life improvements like Surface.fill
    ('black') instead of Surface.fill(pygame.Color(0, 0, 0)). Also
    keywords are supported for many more function arguments. You
    can draw rounded corners on rects.
  * plenty of new examples, like python3 -m pygame.examples.
    font_viewer, and python3 -m pygame.examples.music_drop_fade.
    Additionally the example source code has been cleaned up a lot
    to follow a more current python style.
  * Hundreds of documentation improvements, include a new Korean
    tutorial.
  * a special SCALED mode which takes low pixel games and
    automatically translates them to a larger window. Imagine your
    320x200 resolution game of glorious pixel art... on modern
    screens that would be a very tiny windows. Now with SCALED it
    shows up big on a Full HD screen, or even a 4K/8K screen and
    the translation of mouse coordinates and up-scaling of pixels
    is done for you (hardware accelerated of course).
- Full release notes on https://github.com/pygame/pygame/releases
- Skip python36 build. python36-numpy is not available on TW.
- Drop python-pygame-test-no-mp3.patch and
  python-pygame-python38-import.patch
* Tue Oct 15 2019 Steve Kowalik <steven.kowalik@suse.com>
- Add python-pygame-python38-import.patch from upstream to fix a build
  failure with Python 3.8.
- Use autopatch macro rather than patch0, due to multiple patches.
* Mon May 20 2019 pgajdos@suse.com
- version update to 1.9.6
  * mixer thread deadlock issue when controlling it from different
    threads.
  * pygame.version.vernum now has major, minor, and patch attributes.
- added patches
  Do not test mp3 format.
  + python-pygame-test-no-mp3.patch
* Mon Sep  3 2018 Matěj Cepl <mcepl@suse.com>
- Clean up SPEC, avoid warnings.
* Tue Aug  7 2018 toddrme2178@gmail.com
- Update to 1.9.4
  * python 3.7 support.
  * beta pypy support.
  * pygame.draw fixes
  * pygame.math is not experimental anymore. Speedups and bugfixes.
  * Debian, Mac homebrew, mac virtualenv, manylinux and other platform fixes.
  * documentation fixes, jedi support for type ahead in editors like VSCode and VIM.
  * Surface.blits for blitting many surfaces at once more quickly.
* Wed Jun 13 2018 toddrme2178@gmail.com
- Get tests working.
* Thu Aug 17 2017 jengelh@inai.de
- Fix RPM group.
* Tue Aug  8 2017 toddrme2178@gmail.com
- Update to version 1.9.3
  * This is a bugfix release which fixes a couple of key issues
    which came up with 1.9.2
- Update to version 1.9.2
- Implement single-spec version
- Fix source URL
- Fix shebangs
- Remove pygame-v4l-2.6.38.patch
  No longer needed
* Sun Oct 12 2014 mailaender@opensuse.org
- fixed rpmlint error devel-file-in-non-devel-package
- patch1 could need a tag
- fixed rpmlint warning self-obsoletion pygame-doc
- ignore missing executable flags in the -docs package
- added missing build requires for portmidi
- fixed rpmlint warning files-duplicate with fdupes
- added rpmlintrc to whitelist the warnings about sample code
- avoid redundancy in the %%description
* Thu Jul  7 2011 idonmez@novell.com
- Add pygame-v4l-2.6.38.patch: use new v4l interface
* Tue Jun  8 2010 prusnak@opensuse.org
- updated to 1.9.1
  * add missing readme.html
  * bugfixes
* Wed Aug  5 2009 matejcik@suse.cz
- update to 1.9.0
  * many bugfixes
  * full python-post-2.5 compatibility, py3k compatibility
- patched setup to workaround broken source tarball (missing readme.html)
- removed py2.5 compatibility patch
* Mon May  4 2009 ro@suse.de
- buildrequires: replace python-numeric by python-numpy
  for >= 11.2
* Fri Mar 20 2009 matejcik@suse.cz
- (re)added libpng-devel and libjpeg-devel for image format support
* Fri Sep 12 2008 matejcik@suse.cz
- update to 1.8.1
  * lots of changes and fixes - see WHATSNEW for details
* Sun Jun  1 2008 crrodriguez@suse.de
- needs fno-strict-aliasing
* Thu Apr  3 2008 prusnak@suse.cz
- updated to 1.8.0
  * lots of changes and fixes - see WHATSNEW for details
- rewrite pep353.diff
* Tue Aug 21 2007 meissner@suse.de
- buildrequire SDL_ttf -> SDL_ttf-devel
* Tue Nov 21 2006 prusnak@suse.cz
- changes according to PEP353 (pep353.diff)
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct  6 2005 matejcik@suse.cz
- update to 1.7.1release
- removed readme.html, which is no longer provided
* Wed Feb  2 2005 ro@suse.de
- fix build
* Tue Sep 21 2004 mcihar@suse.cz
- update to 1.6.2, this (among others) fixes brokeness on x86_64 - bug #45731
* Fri Jan 30 2004 mcihar@suse.cz
- fixed documentation installation
* Fri Oct 24 2003 mcihar@suse.cz
- update to 1.6 (This new release mainly contains stability and internal
  fixes, small fixes for line and circle primitives, many fixes for locating
  system TrueType fonts, an updated Mac OS X environment, and bigger integer
  storage for Rect objects.)
- patch was included in upstream
- no root for build
* Thu Oct  2 2003 mcihar@suse.cz
- fixed mode related functions that failed on AMD64, thanks to gpayer@suse.de (bug #31709)
* Mon Jun 16 2003 mcihar@suse.cz
- use record-rpm
- updated to 1.5.6
* Mon May 12 2003 mcihar@suse.cz
- use versioned dependency on python
* Wed Jan  8 2003 mcihar@suse.cz
- added obsoletes and provides for rename
- moved doc into %%{_defaultdocdir}/python-pygame
- some doc is in base package with info where to find more
* Mon Jan  6 2003 mcihar@suse.cz
- update to 1.5.5
  * improved Unicode support
  * fixed some bugs
- renamed to python-pygame
* Mon Aug 12 2002 ro@suse.de
- update to 1.5 to get rid of conflict with pause() from unistd
* Mon Feb 18 2002 vinil@suse.cz
- pygame now requires python
* Mon Feb  4 2002 nadvornik@suse.cz
- update to 1.4
* Tue Jan 29 2002 nadvornik@suse.cz
- new package, version 1.3
